# DB

此处存放数据库操作

## 公共接口

对于不同的数据表类，难免会有一些共同的接口和工具。

### __dict__

该方法为实例方法。

对于 `<Model: cls>` 类型的行数据实例，我们更希望能够直接以字典的格式查看和获取数据，但是 `model_to_dict` 并不能接受这样的类型。
所以我们在每个数据表类中，都配置了一个 `__dict__` 方法，用于在实例的身上下直接获取字典格式的数据。

### create

该方法复写了 `Model` 类的 `create` 方法。

用于指定创建时的一些逻辑：检查外键、配置默认参数等待。
